Types
=====

Configuration Types
-------------------

DHIS2Config
~~~~~~~~~~~

.. autoclass:: pydhis2.core.types.DHIS2Config
   :members:
   :undoc-members:
   :show-inheritance:

Query Types
-----------

AnalyticsQuery
~~~~~~~~~~~~~~

.. autoclass:: pydhis2.core.types.AnalyticsQuery
   :members:
   :undoc-members:
   :show-inheritance:

Error Types
-----------

.. automodule:: pydhis2.core.errors
   :members:
   :undoc-members:
   :show-inheritance:

